==> soma-job-history-0.2.1-sources.jar: br/pucrio/tecgraf/soma/job/application/service/JobService.java <==
package br.pucrio.tecgraf.soma.job.application.service;

import br.pucrio.tecgraf.soma.job.domain.model.Job;
import br.pucrio.tecgraf.soma.job.infrastructure.persistence.repository.JobRepository;
import br.pucrio.tecgraf.soma.job.infrastructure.persistence.specification.JobByIdSpecification;
import br.pucrio.tecgraf.soma.job.infrastructure.persistence.specification.JobsInListSpecification;
import br.pucrio.tecgraf.soma.serviceapi.persistence.repository.Sort;
import br.pucrio.tecgraf.soma.serviceapi.persistence.specification.impl.RSQLSpecification;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

@Service
public class JobService {

  @Autowired private JobRepository jobRepository;

  JobService(JobRepository jobRepository) {
    this.jobRepository = jobRepository;
  }

  @Transactional
  public void markJobAsDeleted(String jobId) {
    Job job = this.jobRepository.first(new JobByIdSpecification(jobId));
    job.setDeleted(true);
    this.jobRepository.update(job);
  }

  @Transactional
  public void markJobsAsDeleted(List<String> jobIds) {
    JobsInListSpecification spec = new JobsInListSpecification(jobIds);
    List<Job> jobs = this.jobRepository.find(spec);
    for (Job job : jobs) {
      job.setDeleted(true);
      this.jobRepository.update(job);
    }
  }

  @Transactional
  public List<Job> findJobs(String rsqlQuery, Boolean ascending, String sortAttribute) {
    return findJobs(rsqlQuery, null, null, ascending, sortAttribute);
  }

  @Transactional
  public List<Job> findJobs(
      String rsqlQuery, Integer offset, Integer limit, Boolean ascending, String sortAttribute) {
    List<Sort> sorts = new ArrayList<>();
    if (ascending != null) {
      sorts.add(new Sort(sortAttribute, ascending));
    }

    return jobRepository.find(
        new RSQLSpecification<>(rsqlQuery, jobRepository.getEntityManager()),
        limit,
        offset,
        sorts.toArray(new Sort[0]));
  }

  @Transactional
  public long count(String rsqlQuery) {
    return jobRepository.count(
        new RSQLSpecification<>(rsqlQuery, jobRepository.getEntityManager()));
  }
}

==> soma-job-history-0.2.4-sources.jar: br/pucrio/tecgraf/soma/job/application/service/JobService.java <==
package br.pucrio.tecgraf.soma.job.application.service;

import br.pucrio.tecgraf.soma.job.domain.model.Job;
import br.pucrio.tecgraf.soma.job.domain.model.JobView;
import br.pucrio.tecgraf.soma.job.infrastructure.persistence.repository.JobRepository;
import br.pucrio.tecgraf.soma.job.infrastructure.persistence.repository.JobViewRepository;
import br.pucrio.tecgraf.soma.job.infrastructure.persistence.specification.JobByIdSpecification;
import br.pucrio.tecgraf.soma.job.infrastructure.persistence.specification.JobsInListSpecification;
import br.pucrio.tecgraf.soma.serviceapi.persistence.repository.Sort;
import br.pucrio.tecgraf.soma.serviceapi.persistence.specification.impl.RSQLSpecification;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

@Service
public class JobService {

  @Autowired private JobRepository jobRepository;
  @Autowired private JobViewRepository jobViewRepository;

  JobService(){
    super();
  }

  JobService(JobRepository jobRepository) {
    this.jobRepository = jobRepository;
  }

  JobService(JobRepository jobRepository, JobViewRepository jobViewRepository) {
    this.jobRepository = jobRepository;
    this.jobViewRepository = jobViewRepository;
  }

  @Transactional
  public void markJobAsDeleted(String jobId) {
    Job job = this.jobRepository.first(new JobByIdSpecification(jobId));
    job.setDeleted(true);
    this.jobRepository.update(job);
  }

  @Transactional
  public void markJobsAsDeleted(List<String> jobIds) {
    JobsInListSpecification spec = new JobsInListSpecification(jobIds);
    List<Job> jobs = this.jobRepository.find(spec);
    for (Job job : jobs) {
      job.setDeleted(true);
      this.jobRepository.update(job);
    }
  }

  @Transactional
  public List<Job> findJobs(String rsqlQuery, Boolean ascending, String sortAttribute) {
    return findJobs(rsqlQuery, null, null, ascending, sortAttribute);
  }

  @Transactional
  public List<Job> findJobs(
      String rsqlQuery, Integer offset, Integer limit, Boolean ascending, String sortAttribute) {
    List<Sort> sorts = new ArrayList<>();
    if (ascending != null) {
      sorts.add(new Sort(sortAttribute, ascending));
    }

    return jobRepository.find(
        new RSQLSpecification<>(rsqlQuery, jobRepository.getEntityManager()),
        limit,
        offset,
        sorts.toArray(new Sort[0]));
  }

  @Transactional
  public List<JobView> findJobsFromView(
    String rsqlQuery, Integer offset, Integer limit, Boolean ascending, String sortAttribute) {
    List<Sort> sorts = new ArrayList<>();
    if (ascending != null) {
      sorts.add(new Sort(sortAttribute, ascending));
    }

    return jobViewRepository.find(
      new RSQLSpecification<>(rsqlQuery, jobViewRepository.getEntityManager()),
      limit,
      offset,
      sorts.toArray(new Sort[0]));
  }

  @Transactional
  public long count(String rsqlQuery) {
    return jobRepository.count(
        new RSQLSpecification<>(rsqlQuery, jobRepository.getEntityManager()));
  }

  @Transactional
  public long countFromView(String rsqlQuery) {
    return jobViewRepository.count(
      new RSQLSpecification<>(rsqlQuery, jobViewRepository.getEntityManager()));
  }
}
